@@ -5,11 +5,11 @@ use strict;
 use warnings;
 use utf8;
 
-use Class::Method::Modifiers qw(fresh);
+use Class::Method::Modifiers 2.04 qw(fresh);
 use HTTP::Tiny;
 use XML::LibXML::Simple qw(XMLin);
 
-our $VERSION = 'v1.2.3'; # VERSION
+our $VERSION = 'v1.2.4'; # VERSION
 
 requires "_make_query_string";
 
